@@ -2,23 +2,21 @@
 #'
 #' This function attempts to return, or compute, p-values of a model's parameters. See the documentation for your object's class:
 #' \itemize{
-#'  \item{\link[=p_value.lmerMod]{Mixed models} (\pkg{lme4}, \pkg{nlme}, \pkg{glmmTMB}, ...)}
-#'  \item{\link[=p_value.BFBayesFactor]{Bayesian models} (\pkg{rstanarm}, \pkg{brms}, \pkg{MCMCglmm}, ...)}
-#'  \item{\link[=p_value.zeroinfl]{Zero-inflated models} (\code{hurdle}, \code{zeroinfl}, \code{zerocount}, ...)}
-#'  \item{\link[=p_value.poissonmfx]{Marginal effects models} (\pkg{mfx})}
-#'  \item{\link[=p_value.DirichletRegModel]{Models with special components} (\code{DirichletRegModel}, \code{clm2}, \code{cgam}, ...)}
+#'  \item{[Bayesian models][p_value.BFBayesFactor] (\pkg{rstanarm}, \pkg{brms}, \pkg{MCMCglmm}, ...)}
+#'  \item{[Zero-inflated models][p_value.zeroinfl] (`hurdle`, `zeroinfl`, `zerocount`, ...)}
+#'  \item{[Marginal effects models][p_value.poissonmfx] (\pkg{mfx})}
+#'  \item{[Models with special components][p_value.DirichletRegModel] (`DirichletRegModel`, `clm2`, `cgam`, ...)}
 #'  }
 #'
 #' @param model A statistical model.
-#' @param method If \code{"robust"}, and if model is supported by the \pkg{sandwich} or \pkg{clubSandwich} packages, computes p-values based on robust covariance matrix estimation.
-#' @param adjust Character value naming the method used to adjust p-values or confidence intervals. See \code{?emmeans::summary.emmGrid} for details.
-#' @param verbose Toggle warnings and messages.
-#' @param ... Arguments passed down to \code{standard_error_robust()} when confidence intervals or p-values based on robust standard errors should be computed. Only available for models where \code{method = "robust"} is supported.
-#' @inheritParams ci.merMod
+#' @param method If `"robust"`, and if model is supported by the \pkg{sandwich} or \pkg{clubSandwich} packages, computes p-values based on robust covariance matrix estimation.
+#' @param adjust Character value naming the method used to adjust p-values or confidence intervals. See `?emmeans::summary.emmGrid` for details.
+#' @param ... Arguments passed down to `standard_error_robust()` when confidence intervals or p-values based on robust standard errors should be computed. Only available for models where `method = "robust"` is supported.
+#' @inheritParams ci.default
 #'
-#' @note \code{p_value_robust()} resp. \code{p_value(method = "robust")}
+#' @note `p_value_robust()` resp. `p_value(robust = TRUE)`
 #'   rely on the \pkg{sandwich} or \pkg{clubSandwich} package (the latter if
-#'   \code{vcov_estimation = "CR"} for cluster-robust standard errors) and will
+#'   `vcov_estimation = "CR"` for cluster-robust standard errors) and will
 #'   thus only work for those models supported by those packages.
 #'
 #' @return A data frame with at least two columns: the parameter names and the p-values. Depending on the model, may also include columns for model components etc.
@@ -38,21 +36,37 @@ p_value <- function(model, ...) {
 
 #' @rdname p_value
 #' @export
-p_value.default <- function(model, method = NULL, verbose = TRUE, ...) {
+p_value.default <- function(model,
+                            dof = NULL,
+                            method = NULL,
+                            robust = FALSE,
+                            component = "all",
+                            verbose = TRUE,
+                            ...) {
   if (!is.null(method)) {
     method <- tolower(method)
   } else {
     method <- "wald"
   }
 
+  # default p-value method for profiled or uniroot CI
+  if (method %in% c("uniroot", "profile", "likelihood", "boot")) {
+    method <- "normal"
+  }
+
   p <- NULL
 
-  if (method == "robust") {
-    return(p_value_robust(model, ...))
-  } else if (method == "ml1") {
+  if (method == "ml1") {
     return(p_value_ml1(model))
   } else if (method == "betwithin") {
     return(p_value_betwithin(model))
+  } else if (method %in% c("residual", "wald", "normal", "satterthwaite", "kenward", "kr")) {
+    if (is.null(dof)) {
+      dof <- degrees_of_freedom(model, method = method, verbose = FALSE)
+    }
+    return(.p_value_dof(model, dof = dof, method = method, component = component, verbose = verbose, robust = robust, ...))
+  } else if (method %in% c("hdi", "eti", "si", "bci", "bcai", "quantile")) {
+    return(bayestestR::p_direction(model, ...))
   } else {
     # first, we need some special handling for Zelig-models
     p <- tryCatch(
@@ -75,7 +89,7 @@ p_value.default <- function(model, method = NULL, verbose = TRUE, ...) {
     p <- tryCatch(
       {
         stat <- insight::get_statistic(model)
-        p_from_stat <- 2 * stats::pnorm(abs(stat$Statistic), lower.tail = FALSE)
+        p_from_stat <- 2 * stats::pt(abs(stat$Statistic), df = Inf, lower.tail = FALSE)
         names(p_from_stat) <- stat$Parameter
         p_from_stat
       },
