@@ -8,6 +8,7 @@
                                               ci = .95,
                                               effects = "random",
                                               component = "conditional",
+                                              ci_method = NULL,
                                               ...) {
   suppressWarnings(
     .extract_random_variances_helper(
@@ -15,6 +16,7 @@
       ci = ci,
       effects = effects,
       component = component,
+      ci_method = ci_method,
       ...
     )
   )
@@ -30,6 +32,7 @@
                                               ci = .95,
                                               effects = "random",
                                               component = "all",
+                                              ci_method = NULL,
                                               ...) {
   component <- match.arg(component, choices = c("all", "conditional", "zero_inflated", "zi", "dispersion"))
 
@@ -39,6 +42,7 @@
       ci = ci,
       effects = effects,
       component = "conditional",
+      ci_method = ci_method,
       ...
     )
   )
@@ -51,6 +55,7 @@
         ci = ci,
         effects = effects,
         component = "zi",
+        ci_method = ci_method,
         ...
       )
     )
@@ -79,45 +84,70 @@
 # workhorse ------------------------
 
 
-.extract_random_variances_helper <- function(model, ci = ci, effects = effects, component = "conditional", ...) {
-  ran_intercept <- data.frame(
-    insight::get_variance(
-      model,
-      component = "intercept",
-      verbose = FALSE,
-      model_component = component
-    )
+.extract_random_variances_helper <- function(model,
+                                             ci = .95,
+                                             effects = "random",
+                                             component = "conditional",
+                                             ci_method = NULL, ...) {
+  ran_intercept <- tryCatch(
+    {
+      data.frame(
+        insight::get_variance(
+          model,
+          component = "intercept",
+          verbose = FALSE,
+          model_component = component
+        )
+      )
+    },
+    error = function(e) {
+      NULL
+    }
   )
 
-  ran_slope <- data.frame(
-    insight::get_variance(
-      model,
-      component = "slope",
-      verbose = FALSE,
-      model_component = component
-    )
+  ran_slope <- tryCatch(
+    {
+      data.frame(
+        insight::get_variance(
+          model,
+          component = "slope",
+          verbose = FALSE,
+          model_component = component
+        )
+      )
+    },
+    error = function(e) {
+      NULL
+    }
   )
 
-  ran_corr <- data.frame(
-    insight::get_variance(
-      model,
-      component = "rho01",
-      verbose = FALSE,
-      model_component = component
-    )
+  ran_corr <- tryCatch(
+    {
+      data.frame(
+        insight::get_variance(
+          model,
+          component = "rho01",
+          verbose = FALSE,
+          model_component = component
+        )
+      )
+    },
+    error = function(e) {
+      NULL
+    }
   )
 
   ran_sigma <- data.frame(insight::get_sigma(model, ci = NULL, verbose = FALSE))
 
   # random intercept - tau00
-  if (nrow(ran_intercept) > 0) {
+  if (!is.null(ran_intercept) && nrow(ran_intercept) > 0) {
     colnames(ran_intercept) <- "Coefficient"
     ran_intercept$Group <- rownames(ran_intercept)
     ran_intercept$Parameter <- "SD (Intercept)"
   }
 
   # random slope - tau11
-  if (nrow(ran_slope) > 0) {
+  if (!is.null(ran_slope) && nrow(ran_slope) > 0) {
     colnames(ran_slope) <- "Coefficient"
     ran_slope$Group <- rownames(ran_slope)
     for (i in unique(ran_intercept$Group)) {
@@ -132,14 +162,29 @@
   }
 
   # random slope-intercept correlation - rho01
-  if (nrow(ran_corr) > 0) {
-    colnames(ran_corr) <- "Coefficient"
-    ran_corr$Group <- rownames(ran_corr)
-    for (i in unique(ran_intercept$Group)) {
-      corrs <- which(grepl(paste0("^\\Q", i, "\\E"), ran_corr$Group))
-      if (length(corrs)) {
-        ran_corr$Parameter[corrs] <- paste0("Cor (Intercept~", i, ")")
-        ran_corr$Group[corrs] <- i
+  if (!is.null(ran_corr) && nrow(ran_corr) > 0) {
+    if (colnames(ran_corr)[1] == ran_intercept$Group[1]) {
+      colnames(ran_corr)[1] <- "Coefficient"
+      ran_corr$Parameter <- paste0("Cor (Intercept~", row.names(ran_corr), ")")
+      ran_corr$Group <- ran_intercept$Group[1]
+    } else {
+      colnames(ran_corr) <- "Coefficient"
+      ran_corr$Group <- rownames(ran_corr)
+      for (i in unique(ran_intercept$Group)) {
+        corrs <- which(grepl(paste0("^\\Q", i, "\\E"), ran_corr$Group))
+        if (length(corrs)) {
+          param_name <- i
+          cor_slopes <- which(grepl(paste0("^\\Q", i, "\\E"), ran_slope$Group))
+          if (length(cor_slopes)) {
+            param_name <- paste0(
+              gsub("SD \\((.*)\\)", "\\1", ran_slope$Parameter[cor_slopes]),
+              ": ",
+              i
+            )
+          }
+          ran_corr$Parameter[corrs] <- paste0("Cor (Intercept~", param_name, ")")
+          ran_corr$Group[corrs] <- i
+        }
       }
     }
   }
@@ -154,9 +199,10 @@
   out <- rbind(ran_intercept, ran_slope, ran_corr, ran_sigma)
   rownames(out) <- NULL
 
-  # variances to SD (sqrt)
+  # variances to SD (sqrt), except correlations and Sigma
   corr_param <- grepl("Cor (Intercept~", out$Parameter, fixed = TRUE)
-  out$Coefficient[!corr_param] <- sqrt(out$Coefficient[!corr_param])
+  sigma_param <- out$Parameter == "SD (Observations)"
+  out$Coefficient[!corr_param & !sigma_param] <- sqrt(out$Coefficient[!corr_param])
 
   stat_column <- gsub("-statistic", "", insight::find_statistic(model), fixed = TRUE)
 
@@ -182,6 +228,31 @@
   }
   out[ci_cols] <- NA
 
+  # add confidence intervals?
+  if (!is.null(ci) && !all(is.na(ci)) && length(ci) == 1 && !is.null(ci_method) && ci_method == "profile") {
+    var_ci <- as.data.frame(suppressWarnings(stats::confint(model, parm = "theta_", oldNames = FALSE, method = "profile", level = ci)))
+    colnames(var_ci) <- c("CI_low", "CI_high")
+
+    rn <- row.names(var_ci)
+    rn <- gsub("sd_(.*)(\\|)(.*)", "\\1: \\3", rn)
+    rn <- gsub("|", ":", rn, fixed = TRUE)
+    rn <- gsub("[\\(\\)]", "", rn)
+    rn <- gsub("cor_(.*)\\.(.*)", "cor \\2", rn)
+
+    var_ci_corr_param <- grepl("^cor ", rn)
+    var_ci_sigma_param <- rn == "sigma"
+
+    out$CI <- ci
+
+    out$CI_low[!corr_param & !sigma_param] <- var_ci$CI_low[!var_ci_corr_param & !var_ci_sigma_param]
+    out$CI_low[sigma_param] <- var_ci$CI_low[var_ci_sigma_param]
+    out$CI_low[corr_param] <- var_ci$CI_low[var_ci_corr_param]
+
+    out$CI_high[!corr_param & !sigma_param] <- var_ci$CI_high[!var_ci_corr_param & !var_ci_sigma_param]
+    out$CI_high[sigma_param] <- var_ci$CI_high[var_ci_sigma_param]
+    out$CI_high[corr_param] <- var_ci$CI_high[var_ci_corr_param]
+  }
+
   out <- out[c("Parameter", "Level", "Coefficient", "SE", ci_cols, stat_column, "df_error", "p", "Effects", "Group")]
 
   if (effects == "random") {
