@@ -3,7 +3,6 @@
 model_parameters.MixMod <- model_parameters.glmmTMB
 
 
-#' @rdname ci.merMod
 #' @export
 ci.MixMod <- function(x,
                       ci = .95,
@@ -11,10 +10,17 @@ ci.MixMod <- function(x,
                       verbose = TRUE,
                       ...) {
   component <- match.arg(component)
+
   if (is.null(.check_component(x, component, verbose = verbose))) {
     return(NULL)
   }
-  ci_wald(model = x, ci = ci, dof = Inf, component = component)
+
+  .ci_generic(
+    model = x,
+    ci = ci,
+    dof = Inf,
+    component = component
+  )
 }
 
 
@@ -29,9 +35,7 @@ standard_error.MixMod <- function(model,
   effects <- match.arg(effects)
 
   if (effects == "random") {
-    if (!requireNamespace("lme4", quietly = TRUE)) {
-      stop("Package 'lme4' required to calculate standard errors for random effects. Please install it.")
-    }
+    insight::check_if_installed("lme4")
     rand.se <- lme4::ranef(model, post_vars = TRUE)
     vars.m <- attr(rand.se, "post_vars")
     all_names <- attributes(rand.se)$dimnames
@@ -60,7 +64,11 @@ standard_error.MixMod <- function(model,
     cs <- .compact_list(cs)
     x <- lapply(names(cs), function(i) {
       .data_frame(
-        Parameter = insight::find_parameters(model, effects = "fixed", component = i, flatten = TRUE),
+        Parameter = insight::find_parameters(model,
+          effects = "fixed",
+          component = i,
+          flatten = TRUE
+        ),
         SE = as.vector(cs[[i]][, 2]),
         Component = i
       )
@@ -72,9 +80,11 @@ standard_error.MixMod <- function(model,
 }
 
 
-#' @rdname p_value.lmerMod
 #' @export
-p_value.MixMod <- function(model, component = c("all", "conditional", "zi", "zero_inflated"), verbose = TRUE, ...) {
+p_value.MixMod <- function(model,
+                           component = c("all", "conditional", "zi", "zero_inflated"),
+                           verbose = TRUE,
+                           ...) {
   component <- match.arg(component)
   if (is.null(.check_component(model, component, verbose = verbose))) {
     return(NULL)
@@ -86,7 +96,11 @@ p_value.MixMod <- function(model, component = c("all", "conditional", "zi", "zer
   cs <- .compact_list(cs)
   x <- lapply(names(cs), function(i) {
     .data_frame(
-      Parameter = insight::find_parameters(model, effects = "fixed", component = i, flatten = TRUE),
+      Parameter = insight::find_parameters(model,
+        effects = "fixed",
+        component = i,
+        flatten = TRUE
+      ),
       p = as.vector(cs[[i]][, 4]),
       Component = i
     )
