@@ -1,11 +1,14 @@
-#' @param method The method used in the variable selection. Can be \code{NULL} (default), \code{"forward"} or \code{"L1"}. See \code{projpred::varsel}.
+#' @param method The method used in the variable selection. Can be `NULL`
+#'   (default), `"forward"` or `"L1"`. See `projpred::varsel`.
 #' @param cross_validation Select with cross-validation.
 #' @rdname select_parameters
 #' @export
-select_parameters.stanreg <- function(model, method = NULL, cross_validation = FALSE, ...) {
-  if (!requireNamespace("projpred", quietly = TRUE)) {
-    stop("Package 'projpred' required for this function to work. Please install it by running `install.packages('projpred')`.")
-  }
+
+select_parameters.stanreg <- function(model,
+                                      method = NULL,
+                                      cross_validation = FALSE,
+                                      ...) {
+  insight::check_if_installed("projpred")
 
   if (cross_validation) {
     message("Cross-validating best parameters...")
@@ -34,10 +37,6 @@ select_parameters.stanreg <- function(model, method = NULL, cross_validation = F
 select_parameters.brmsfit <- select_parameters.stanreg
 
 
-
-
-
-
 #' @keywords internal
 .reconstruct_formula <- function(parameters, model) {
 
