@@ -1,4 +1,4 @@
-if (require("testthat") && require("lme4") && require("parameters")) {
+if (requiet("testthat") && requiet("lme4") && requiet("parameters")) {
   data(mtcars)
   test_that("ci", {
     model <- lm(mpg ~ wt, data = mtcars)
@@ -9,7 +9,10 @@ if (require("testthat") && require("lme4") && require("parameters")) {
     expect_equal(ci(model)[1, 3], 1.934013, tolerance = 0.01)
 
     model <- lme4::lmer(wt ~ cyl + (1 | gear), data = mtcars)
-    expect_equal(ci(model)[1, 3], -0.335063, tolerance = 0.01)
+    expect_equal(ci(model, method = "normal")[1, 3], -0.335063, tolerance = 0.01)
+
+    model <- lme4::lmer(wt ~ cyl + (1 | gear), data = mtcars)
+    expect_equal(ci(model)[1, 3], -0.3795646, tolerance = 0.01)
 
     set.seed(1)
     val <- ci(model, method = "boot")[1, 3]
