@@ -1,23 +1,41 @@
 .runThisTest <- Sys.getenv("RunAllparametersTests") == "yes"
 
 if (.runThisTest &&
-  require("testthat") &&
-  require("parameters") &&
-  require("lme4")) {
+  requiet("testthat") &&
+  requiet("parameters") &&
+  requiet("lme4")) {
   data(mtcars)
   m1 <- lme4::lmer(wt ~ cyl + (1 | gear), data = mtcars)
   m2 <- lme4::glmer(vs ~ cyl + (1 | gear), data = mtcars, family = "binomial")
 
   test_that("model_parameters.mixed", {
-    params <- model_parameters(m1, effects = "fixed")
+    params <- model_parameters(m1, ci_method = "normal", effects = "fixed")
     expect_equal(c(nrow(params), ncol(params)), c(2, 10))
     expect_equal(params$CI_high, c(1.6373105660317, 0.554067677205595), tolerance = 1e-3)
 
-    params <- model_parameters(m1, ci = c(0.8, 0.9), effects = "fixed")
+    params <- model_parameters(m1, effects = "fixed")
+    expect_equal(c(nrow(params), ncol(params)), c(2, 10))
+    expect_equal(params$CI_high, c(1.68181, 0.56083), tolerance = 1e-3)
+
+    params <- model_parameters(m1, ci = c(0.8, 0.9), ci_method = "normal", effects = "fixed")
     expect_equal(c(nrow(params), ncol(params)), c(2, 12))
     expect_equal(params$CI_high_0.8, c(1.29595665381331, 0.502185700948862), tolerance = 1e-3)
     expect_equal(params$CI_high_0.9, c(1.47875781798108, 0.529969433080186), tolerance = 1e-3)
 
+    params <- model_parameters(m1, ci_method = "normal", effects = "fixed")
+    lme4_ci <- na.omit(as.data.frame(confint(m1, method = "Wald")))
+    expect_equal(params$CI_low, lme4_ci$`2.5 %`, tolerance = 1e-4)
+
+    params <- model_parameters(m1, ci = c(0.8, 0.9), ci_method = "wald", effects = "fixed")
+    expect_equal(c(nrow(params), ncol(params)), c(2, 12))
+    expect_equal(params$CI_high_0.8, c(1.31154, 0.50455), tolerance = 1e-3)
+    expect_equal(params$CI_high_0.9, c(1.50707, 0.53427), tolerance = 1e-3)
+
+    params <- model_parameters(m1, ci = c(0.8, 0.9), effects = "fixed")
+    expect_equal(c(nrow(params), ncol(params)), c(2, 12))
+    expect_equal(params$CI_high_0.8, c(1.31154, 0.50455), tolerance = 1e-3)
+    expect_equal(params$CI_high_0.9, c(1.50707, 0.53427), tolerance = 1e-3)
+
     params <- model_parameters(m2, effects = "fixed")
     expect_equal(c(nrow(params), ncol(params)), c(2, 10))
 
@@ -50,7 +68,7 @@ if (.runThisTest &&
       as.vector(params$Parameter),
       c("SD (Intercept)", "SD (Observations)")
     )
-    expect_equal(params$Coefficient, c(0.27049, 0.77061), tolerance = 1e-2)
+    expect_equal(params$Coefficient, c(0.27049, 0.59385), tolerance = 1e-2)
   })
 
   test_that("model_parameters.mixed-all", {
@@ -60,7 +78,7 @@ if (.runThisTest &&
       as.vector(params$Parameter),
       c("(Intercept)", "cyl", "SD (Intercept)", "SD (Observations)")
     )
-    expect_equal(params$Coefficient, c(0.65112, 0.40418, 0.27049, 0.77617), tolerance = 1e-2)
+    expect_equal(params$Coefficient, c(0.65112, 0.40418, 0.27049, 0.59385), tolerance = 1e-2)
   })
 
   test_that("model_parameters.mixed-all_pars", {
@@ -98,20 +116,20 @@ if (.runThisTest &&
       c(
         "Parameter   | Coefficient |   SE |         95% CI | t(558) |      p",
         "-------------------------------------------------------------------",
-        "(Intercept) |       71.53 | 1.56 | [68.48, 74.58] |  45.98 | < .001",
-        "time        |        1.09 | 0.64 | [-0.16,  2.34] |   1.70 | 0.088 ",
+        "(Intercept) |       71.53 | 1.56 | [68.48, 74.59] |  45.98 | < .001",
+        "time        |        1.09 | 0.64 | [-0.17,  2.34] |   1.70 | 0.089 ",
         "",
         "# Within-Effects",
         "",
         "Parameter   | Coefficient |   SE |         95% CI | t(558) |      p",
         "-------------------------------------------------------------------",
-        "phq4_within |       -3.66 | 0.41 | [-4.46, -2.86] |  -8.95 | < .001",
+        "phq4 within |       -3.66 | 0.41 | [-4.46, -2.86] |  -8.95 | < .001",
         "",
         "# Between-Effects",
         "",
         "Parameter    | Coefficient |   SE |         95% CI | t(558) |      p",
         "--------------------------------------------------------------------",
-        "phq4_between |       -6.28 | 0.50 | [-7.27, -5.30] | -12.53 | < .001"
+        "phq4 between |       -6.28 | 0.50 | [-7.27, -5.30] | -12.53 | < .001"
       )
     )
   })
@@ -125,15 +143,15 @@ if (.runThisTest &&
         "",
         "Parameter   | Coefficient |   SE |        95% CI | t(28) |      p",
         "-----------------------------------------------------------------",
-        "(Intercept) |        0.65 | 0.50 | [-0.34, 1.64] |  1.29 | 0.196 ",
-        "cyl         |        0.40 | 0.08 | [ 0.25, 0.55] |  5.29 | < .001",
+        "(Intercept) |        0.65 | 0.50 | [-0.38, 1.68] |  1.29 | 0.206 ",
+        "cyl         |        0.40 | 0.08 | [ 0.25, 0.56] |  5.29 | < .001",
         "",
         "# Random Effects",
         "",
         "Parameter            | Coefficient",
         "----------------------------------",
         "SD (Intercept: gear) |        0.27",
-        "SD (Residual)        |        0.77"
+        "SD (Residual)        |        0.59"
       )
     )
 
@@ -145,8 +163,8 @@ if (.runThisTest &&
         "",
         "Parameter   | Coefficient |   SE |        95% CI | t(28) |      p",
         "-----------------------------------------------------------------",
-        "(Intercept) |        0.65 | 0.50 | [-0.34, 1.64] |  1.29 | 0.196 ",
-        "cyl         |        0.40 | 0.08 | [ 0.25, 0.55] |  5.29 | < .001",
+        "(Intercept) |        0.65 | 0.50 | [-0.38, 1.68] |  1.29 | 0.206 ",
+        "cyl         |        0.40 | 0.08 | [ 0.25, 0.56] |  5.29 | < .001",
         "",
         "Model: wt ~ cyl (32 Observations)",
         "Residual standard deviation: 0.594 (df = 28)",
