@@ -1,4 +1,4 @@
-if (require("testthat") && require("parameters")) {
+if (requiet("testthat") && requiet("parameters")) {
   test_that("model_parameters.pairwise.htest", {
     data(airquality)
     airquality$Month <- factor(airquality$Month, labels = month.abb[5:9])
